==> cdk-eks-karpenter-0.0.15.tar.gz: cdk-eks-karpenter-0.0.15/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-eks-karpenter",
    "version": "0.0.15",
    "description": "CDK construct library that allows you install Karpenter in an AWS EKS cluster",
    "license": "Apache-2.0",
    "url": "https://github.com/aws-samples/cdk-eks-karpenter.git",
    "long_description_content_type": "text/markdown",
    "author": "Andreas Lindh<elindh@amazon.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws-samples/cdk-eks-karpenter.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_eks_karpenter",
        "cdk_eks_karpenter._jsii"
    ],
    "package_data": {
        "cdk_eks_karpenter._jsii": [
            "cdk-eks-karpenter@0.0.15.jsii.tgz"
        ],
        "cdk_eks_karpenter": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.12.0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.57.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> cdk-eks-karpenter-0.0.18.tar.gz: cdk-eks-karpenter-0.0.18/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-eks-karpenter",
    "version": "0.0.18",
    "description": "CDK construct library that allows you install Karpenter in an AWS EKS cluster",
    "license": "Apache-2.0",
    "url": "https://github.com/aws-samples/cdk-eks-karpenter.git",
    "long_description_content_type": "text/markdown",
    "author": "Andreas Lindh<elindh@amazon.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws-samples/cdk-eks-karpenter.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_eks_karpenter",
        "cdk_eks_karpenter._jsii"
    ],
    "package_data": {
        "cdk_eks_karpenter._jsii": [
            "cdk-eks-karpenter@0.0.18.jsii.tgz"
        ],
        "cdk_eks_karpenter": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.12.0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.71.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
